Transition-based Feature Generator (TFGen)
==========================================
The process log/event log will be used as input for the feature generator. The feature generator will generate transition matrices.
